stormtracks API — stormtracks 0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- stormtracks 0.1 documentation »

# stormtracks API

Contents

- stormtracks API
  - Running
    - `stormtracks.download` – Download Necessary Data
    - `stormtracks.run_stormtracks` – Run the Project
  - Main Modules
    - `stormtracks.c20data` – C20 Reanalysis Data
    - `stormtracks.ibtracsdata` – IBTrACS Data
    - `stormtracks.tracking` – Tracking of Features
    - `stormtracks.tracking` – Matching of Tracks
    - `stormtracks.results` – Store and Access Results
  - Utilities
  - Running in Cluster Mode

## Running

### `stormtracks.download` – Download Necessary Data

`stormtracks.download.` `download_full_c20`(year)

  Downloads each ensemble member’s values for prmsl, u and v

`stormtracks.download.` `download_full_c20_range`(start_year, end_year)

  Downloads each ensemble member’s values for prmsl, u and v in a given range

`stormtracks.download.` `download_mean_c20`(year)

  Downloads mean values for prmsl, u and v

`stormtracks.download.` `download_mean_c20_range`(start_year, end_year)

  Downloads mean values for prmsl, u and v in a given range

### `stormtracks.run_stormtracks` – Run the Project

## Main Modules

### `stormtracks.c20data` – C20 Reanalysis Data

class `stormtracks.c20data.` `GlobalEnsembleMember`(c20data, ensemble_member=0)

  Wrapper around a C20Data object that holds state of which ensemble member is currently being analysed

### `stormtracks.ibtracsdata` – IBTrACS Data

### `stormtracks.tracking` – Tracking of Features

class `stormtracks.tracking.` `VortMax`(date, pos, vort)

  Holds key info (date, position, vorticity value) about a vorticity maximum.

  To serialize this class (or any that contain objects of this class) you must make sure next_vortmax/prev_vortmax are None.

class `stormtracks.tracking.` `VortMaxTrack`(start_vortmax)

  Stores a collection of VortMax objects in a list and adds them to a dict that is accessible through a date for easy access.

### `stormtracks.tracking` – Matching of Tracks

### `stormtracks.results` – Store and Access Results

## Utilities

`stormtracks.utils.utils.` `dist`(p1, p2)

  Returns the cartesian distance between two points

`stormtracks.utils.utils.` `find_extrema`(array)

  Takes an array and finds its local extrema.

  Returns an array with 0s for not an extrema, 1s for maxs and -1 for mins and a list of the indices of all maximums and minimums

  N.B. this function is much faster than the above.

`stormtracks.utils.utils.` `find_extrema_slow`(array, print_warning=True)

  Takes an array and finds its local extrema.

  Returns an array with 0s for not an extrema, 1s for maxs and -1 for mins and a list of the indices of all maximums and minimums

`stormtracks.utils.utils.` `geo_dist`(p1, p2)

  Returns the geodesic distance between two points

`stormtracks.utils.utils.` `pairwise`(iterable)

  s -> (s0,s1), (s1,s2), (s2, s3), ...

`stormtracks.utils.utils.` `raster_voronoi`(extrema, maximums, minimums)

  Takes a 2D array and points of max/mins, and returns a 2D array with the voronoi sections filled with different values

`stormtracks.utils.utils.` `upscale_field`(lons, lats, field, x_scale=2, y_scale=2, is_degrees=True)

  Takes a field defined on a sphere using lons/lats and returns an upscaled version, using cubic spline interpolation.

## Running in Cluster Mode

- stormtracks Running in Cluster Mode

### Navigation

- index
- modules |
- next |
- previous |
- stormtracks 0.1 documentation »